# Copyright (c) 2000-2008, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

# If you want repolib package to be built,
# issue the following: 'rpmbuild --with repolib'

%define _with_repolib 1

%define with_repolib %{?_with_repolib:1}%{!?_with_repolib:0}
%define without_repolib %{!?_with_repolib:1}%{?_with_repolib:0}

%define repodir %{_javadir}/repository.jboss.com/javassist//%{version}.%{reltag}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%define section free

%define reltag  GA

Summary:        Java Programming Assistant: bytecode manipulation
Name:           javassist
Version:        3.8.0
Release:	2%{?dist}
Epoch:          0
License:        MPL and LGPL
URL:            http://www.csg.is.titech.ac.jp/~chiba/javassist/
Group:          Development/Libraries/Java
# cvs -d:pserver:anonymous@anoncvs.forge.jboss.com:/cvsroot/jboss export -r rel_3_8_0_ga javassist
# tar czf javassist-rel_3_8_0_ga-src.tar.gz javassist
Source0:        javassist-rel_3_8_0_ga-src.tar.gz
Source1:	javassist-component-info.xml

BuildRequires:  jpackage-utils >= 0:1.7
BuildRequires:  ant >= 0:1.6
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
Javassist (Java Programming Assistant) makes Java 
bytecode manipulation simple. It is a class library 
for editing bytecodes in Java; it enables Java 
programs to define a new class at runtime and to 
modify a class file when the JVM loads it. Unlike 
other similar bytecode editors, Javassist provides 
two levels of API: source level and bytecode level. 
If the users use the source-level API, they can edit 
a class file without knowledge of the specifications 
of the Java bytecode. The whole API is designed with 
only the vocabulary of the Java language. You can even 
specify inserted bytecode in the form of source text; 
Javassist compiles it on the fly. On the other hand, 
the bytecode-level API allows the users to directly 
edit a class file as other editors. 

%if %{with_repolib}
%package	 repolib
Summary:	 Artifacts to be uploaded to a repository library
Group:	Development/Libraries/Java

%description	 repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio
%endif

%package demo
Summary:        Samples for %{name}
Group:          Development/Documentation
Requires:       javassist = 0:%{version}-%{release}

%description demo
%{summary}.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
%{summary}.

%package manual
Summary:        Tutorial for %{name}
Group:          Development/Documentation

%description manual
%{summary}.

%prep
%setup -q -n %{name}
for j in $(find . -name "*.jar"); do
        mv $j $j.no
done

sed -i 's/@VERSION@/%{version}.%{reltag}-brew/g' %{SOURCE1}
tag=`echo %{name}-%{version}-%{release} | sed 's|\.|_|g'`
sed -i "s/@TAG@/$tag/g" %{SOURCE1}

mkdir tmpsrc

pushd src/main 2>&1 > /dev/null && \
        jar -cf ../../tmpsrc/%{name}-src.jar %{name} && \
popd 2>&1 > /dev/null

%build
ant dist

%install
rm -rf $RPM_BUILD_ROOT

# jars
mkdir -p $RPM_BUILD_ROOT%{_javadir}
cp -p %{name}.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`; done)

# demo
mkdir -p $RPM_BUILD_ROOT%{_datadir}/%{name}-%{version}
cp -pr sample/* $RPM_BUILD_ROOT%{_datadir}/%{name}-%{version}

# javadoc
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr html/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name} # ghost symlink

# manual
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}/tutorial
cp -pr tutorial/* $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}/tutorial
cp -p License.html $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}


%if %{with_repolib}
	install -d -m 755 $RPM_BUILD_ROOT%{repodir}
	install -d -m 755 $RPM_BUILD_ROOT%{repodirlib}
	install -m 755 %{SOURCE1} $RPM_BUILD_ROOT%{repodir}/component-info.xml
	install -d -m 755 $RPM_BUILD_ROOT%{repodirsrc}
	install -m 755 %{SOURCE0} $RPM_BUILD_ROOT%{repodirsrc}
	cp $RPM_BUILD_ROOT%{_javadir}/javassist.jar $RPM_BUILD_ROOT%{repodirlib}
	cp tmpsrc/%{name}-src.jar $RPM_BUILD_ROOT%{repodirlib}
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post javadoc
rm -f %{_javadocdir}/%{name}
ln -s %{name}-%{version} %{_javadocdir}/%{name}

%postun javadoc
if [ "$1" = "0" ]; then
  rm -f %{_javadocdir}/%{name}
fi

%files
%defattr(0644,root,root,0755)
%doc %{_docdir}/%{name}-%{version}/License.html
%{_javadir}/*.jar

%files demo
%defattr(0644,root,root,0755)
%{_datadir}/%{name}-%{version}

%files javadoc
%defattr(0644,root,root,0755)
%doc %{_javadocdir}/%{name}-%{version}
%ghost %doc %{_javadocdir}/%{name}

%files manual
%defattr(0644,root,root,0755)
%doc %{_docdir}/%{name}-%{version}/tutorial


%if %{with_repolib}
%files repolib
%defattr(0644,root,root,0755)
%{repodir}
%endif

%changelog
* Mon Dec 08 2008 Will Tatam <will.tatam@red61.com> 3.8.0-2
- Auto rebuild for JPackage 5 in mock

* Mon Jul 14 2008 Fernando Nasser <fnasser@redhat.com> - 0:3.8.0-1
- Upgrade to 3.8.0

* Mon Jun 2 2008 Permaine Cheung <pcheung@redhat.com> - 0:3.6.0-2
- First JPP5 build

* Tue Oct 3 2007 Clive Saldanha <csaldanh@redhat.com> - 0:3.6.0-1jpp.ep1.2
- Rebuilding with 1.4 

* Tue Oct 2 2007 Clive Saldanha <csaldanh@redhat.com> - 0:3.6.0-1jpp.ep1.1
- Upgrade to 3.6.0.GA 

* Fri May 4 2007 Vivek Lakshmanan <vivekl@redhat.com> - 0:3.5.0-1jpp.ep1.5
- Replace 3.5.0-brew with 3.5.0.GA-brew

* Wed May 2 2007 Vivek Lakshmanan <vivekl@redhat.com> - 0:3.5.0-1jpp.ep1.4
- Respun with fresh export of rel_3_5_GA tag

* Wed May 2 2007 Vivek Lakshmanan <vivekl@redhat.com> - 0:3.5.0-1jpp.ep1.3
- Respun with fresh export of Javassist_3_5_0_GA tag

* Mon Apr 30 2007 Vivek Lakshmanan <vivekl@redhat.com> - 0:3.5.0-1jpp.ep1.2
- Fix component-info.xml and specś reference to directory locations in repolib

* Mon Apr 30 2007 Deepak Bhole <dbhole@redhat.com> - 0:3.5.0-1jpp.ep1.1
- Upgrade to 3.5.0 GA

* Tue Mar 13 2007 Fernando Nasser <fnasser@redhat.com> - 0:3.5-0.cr1.2jpp.ep1.1
- Rebuild

* Thu Mar 1 2007 Vivek Lakshmanan <vivekl@redhat.com> - 0:3.5-0.cr1.2jpp.el4ep1.4
- Add src jar to lib directory and component-info.xml

* Tue Feb 20 2007 Vivek Lakshmanan <vivekl@redhat.com> - 0:3.5-0.cr1.2jpp.el4ep1.3
- Add -brew suffix

* Sat Feb 17 2007 Vivek Lakshmanan <vivekl@redhat.com> - 0:3.5-0.cr1.2jpp.el4ep1.2
- Add repolib support

* Sat Feb 17 2007 Fernando Nasser <fnasser@redhat.com> - 0:3.5-0.cr1.2jpp.el4ep1.1
- Merge with upstream for upgrade

* Sat Feb 17 2007 Fernando Nasser <fnasser@redhat.com> - 0:3.5-0.cr1.2jpp
- Remove vendor and distribution tags
- Remove tabs

* Sat Feb 17 2007 Fernando Nasser <fnasser@redhat.com> - 0:3.5-0.cr1.1jpp
- Upgrade to 3.5.CR1

* Tue Aug 01 2006 Fernando Nasser <fnasser@redhat.com> - 0:3.2-0.cr2.1jpp_1rh
- Merge with upstream

* Tue Jun 13 2006 Ralph Apel <r.apel@r-apel.de> - 0:3.2-0.cr2.1jpp
- Upgrade to 3.2.CR2

* Fri May 19 2006 Fernando Nasser <fnasser@redhat.com> - 0:3.1-1jpp_1rh
- Merge with upstream for upgrade

* Tue May 02 2006 Ralph Apel <r.apel@r-apel.de> - 0:3.1-1jpp
- Upgrade to 3.1

* Sat Feb 25 2006 Fernando Nasser <fnasser@redhat.com> - 0:3.0-2jpp_1rh
- First Red Hat build

* Fri Feb 24 2006 Fernando Nasser <fnasser@redhat.com> - 0:3.0-2jpp
- First JPP 1.7 build

* Fri Mar 04 2005 Ralph Apel <r.apel at r-apel.de> - 0:3.0-1jpp
- Upgrade to 3.0 final
- Fixed _docdir ownership

* Sun Aug 23 2004 Randy Watler <rwatler at finali.com> - 0:3.0-0.beta.2jpp
- Rebuild with ant-1.6.2

* Fri Jun 04 2004 Ralph Apel <r.apel at r-apel.de> - 0:3.0-0.beta.1jpp
- preview of 3.0

* Fri Mar 05 2004 Ralph Apel <r.apel at r-apel.de> - 0:2.6-1jpp
- First JPackage release
